StructuralRule

Struct StructuralRule 

pub struct StructuralRule {
Show 14 fields pub on: String, pub not_on: Option<String>, pub target: Option<StructuralSymbolKind>, pub must_be: Option<Vec<StructuralSymbolKind>>, pub must_be_named: Option<String>, pub must_be_final: Option<bool>, pub must_be_abstract: Option<bool>, pub must_be_readonly: Option<bool>, pub must_implement: Option<StructuralInheritanceConstraint>, pub must_extend: Option<StructuralInheritanceConstraint>, pub must_use_trait: Option<StructuralInheritanceConstraint>, pub must_use_attribute: Option<StructuralInheritanceConstraint>, pub only_public_methods: Option<Vec<String>>, pub reason: Option<String>,
}
Represents a single structural enforcement rule from [[guard.structural.rules]].

Fields

on: String

The namespace pattern this rule applies to.

not_on: Option<String>

An optional exclusion pattern; if the namespace matches this, the rule is skipped.

target: Option<StructuralSymbolKind>

The kind of symbol this policy applies to (e.g., “class”).

must_be: Option<Vec<StructuralSymbolKind>>

Restricts the namespace to only contain the specified symbol kinds.

must_be_named: Option<String>

Optional naming pattern the symbol’s name must match.

must_be_final: Option<bool>

If true, the symbol must be declared final.

must_be_abstract: Option<bool>

If true, the symbol must be declared abstract.

must_be_readonly: Option<bool>

If true, the symbol must be declared readonly.

must_implement: Option<StructuralInheritanceConstraint>

Structural implementation constraints.

must_extend: Option<StructuralInheritanceConstraint>

Structural extension constraints.

must_use_trait: Option<StructuralInheritanceConstraint>

Structural trait usage constraints.

must_use_attribute: Option<StructuralInheritanceConstraint>

Structural attribute usage constraints.

only_public_methods: Option<Vec<String>>

The public methods that matched classes may declare. Private and protected methods are unrestricted.

reason: Option<String>

A human-readable reason for this rule.